.. planarity documentation master file, created by
   sphinx-quickstart on Thu Jun 30 15:49:39 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Planarity
=========

A Python interface to graph planarity algorithms.

This provides a wrapper for Boyer's (C) planarity algorithms:
http://code.google.com/p/planarity/

:Release: |version|
:Date: |today|


Functions
---------

.. automodule:: planarity.planarity_functions
   :members:

NetworkX Interface
------------------
.. automodule::  planarity.planarity_networkx
   :members:


Wrapper Class
-------------

.. autoclass::  planarity.PGraph

.. automethod:: ascii


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

